@@ -65,8 +65,10 @@ gint gnome_print_pdf_object_start (GnomePrintPdf *pdf, gint object_number, gbool
 gint gnome_print_pdf_object_end   (GnomePrintPdf *pdf, gint object_number, gboolean dont_print);
 
 /* Type 1 & TrueType embed */
+void gnome_print_embed_pdf_font  (GnomePrintPdf *pdf, GnomePrintPdfFont *font);
 gint gnome_print_pdf_t1_embed (GnomePrintPdf *pdf, const guchar *file_name, gint *object_number);
 gint gnome_print_pdf_tt_embed (GnomePrintPdf *pdf, const guchar *file_name, gint *object_number);
+gint gnome_print_pdf_tt_subset_embed (GnomePrintPdf *pdf, GnomePrintPdfFont *font, const guchar *file_name, gint *object_number);
 
 
 G_END_DECLS
